VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "clsMSTRConnection"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False


Option Explicit

'*******************************************************************************
'
' Global variables within the class
'
'*******************************************************************************

Public objDSE As DSSDataSourceEnumerator
Public objDS As DSSDataSource
Public objSession As IDSSSession

Public bolSession As Boolean               ' indicates session status (true=open)


'*******************************************************************************
'
' Function:     destroyMSTRVars
'
' FunctionID:   0
'
' Author:       Hanno Wiegard
'
' Purpose:      destroy all variables within this module
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     None
'       IN/OUT: None
'       OUT:    None
'
'-------------------------------------------------------------------------------
'
' History:  06/17/2000  HW  Creation
'
'*******************************************************************************

Private Sub destroyMSTRVars()

On Error GoTo err_Handler

Set objDSE = Nothing
Set objDS = Nothing
Set objSession = Nothing

Exit Sub

' Do the error handling
err_Handler:

' raise error with the original error number if error was not handled before
'Err.Raise ERR_DESTROY_VARIABLES_GENERAL, "modMSTR7Helper:readProjects", Err.Number & ":" & Err.Number

End Sub

'*******************************************************************************
'
' End of Function:     destroyMSTRVars
'
'*******************************************************************************




'*******************************************************************************
'
' Function:     readProjectSources
'
' FunctionID:   1
'
' Author:       Hanno Wiegard
'
' Purpose:      Read the project sources saved in the registry of a computer
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     None
'       IN/OUT: None
'       OUT:    strProjectSources   - The list of project sources (result)
'               strErrorMessage     - error message if not successful
'                                     empty string  otherwise
'
'-------------------------------------------------------------------------------
'
' History:  06/17/2000  HW  Creation
'
'*******************************************************************************

Function readProjectSources(strProjectSources() As String, strErrorMessage As String) As Boolean

Dim intCounter As Integer

On Error GoTo err_Handler

' assume failure of the this function
readProjectSources = False

' Create new DataSourceEnumerator to list the project sources stored in the registry
Set objDSE = New DSSDataSourceEnumerator

' Load registry content
objDSE.LoadFromRegistry

' resize resulting projectsources array but reduce the size by 1 (array starts at 0)
ReDim strProjectSources(objDSE.Count - 1, 2)

For intCounter = 1 To objDSE.Count
    strProjectSources(intCounter - 1, 1) = objDSE.Item(intCounter).Name
    strProjectSources(intCounter - 1, 2) = objDSE.Item(intCounter).Type
Next

readProjectSources = True
Exit Function

' Do the error handling
err_Handler:

' raise error with the original error number if error was not handled before
'Err.Raise ERR_READ_PROJECTSOURCES_GENERAL, "modMSTR7Helper:readProjectSources", Err.Number & ":" & Err.Number & ":" & Err.Source

End Function

'*******************************************************************************
'
' End of Function:     readProjectSources
'
'*******************************************************************************




'*******************************************************************************
'
' Function:     LogIntoProjectSource
'
' FunctionID:   2
'
' Author:       Hanno Wiegard
'
' Purpose:      logs user with the given userid and password into the project source
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     strUID              - username for the project
'               strPWD              - password for the project
'               bolNTSecurity       - use NT security (true = yes)
'               intProjectSource    - index of the project source
'       IN/OUT: None
'       OUT:    strErrorMessage     - error message if not successful
'                                     empty string  otherwise
'
'-------------------------------------------------------------------------------
'
' History:  06/17/2000  HW  Creation
'
'*******************************************************************************

Function LogIntoProjectSource(strUID As String, strPWD As String, bolNTSecurity As Boolean, intProjectSource As Integer, strErrorMessage As String) As Boolean

On Error GoTo err_Handler

' assume failure of the this function
LogIntoProjectSource = False

' Set Data Source to the selected project (identified by the id)
Set objDS = objDSE.Item(intProjectSource + 1)

If bolNTSecurity Then
    objDS.AuthMode = DssAuthNTCredential
Else
    objDS.AuthMode = DssAuthStandard
    objDS.login = strUID
    objDS.Passwd = strPWD
End If

' initialize Data Source
objDS.Init

LogIntoProjectSource = True
Exit Function

' Do the error handling
err_Handler:

' raise error with the original error number if error was not handled before
'strErrorMessage = ERR_LOGINTOPPROEJCTSOURCE_GENERAL & " : modMSTR7Helper:LogIntoProjectSource:" & Err.Number & ":" & Err.Description & ":" & Err.Source

End Function

'*******************************************************************************
'
' End of Function:     LogIntoProjectSource
'
'*******************************************************************************




'*******************************************************************************
'
' Function:     readProjects
'
' FunctionID:   3
'
' Author:       Hanno Wiegard
'
' Purpose:      reads the projects for a data source
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     None
'       IN/OUT: None
'       OUT:    strProjects         - The list of project sources (result)
'               strErrorMessage     - error message if not successful
'                                     empty string  otherwise
'
'-------------------------------------------------------------------------------
'
' History:  06/17/2000  HW  Creation
'
'*******************************************************************************

Function readProjects(strProjects() As String, strErrorMessage As String) As Boolean

Dim intCounter As Integer
Dim objProjectDS As DSSDataSource

On Error GoTo err_Handler

' assume failure of the this function
readProjects = False

' resize resulting projectsources array but reduce the size by 1 (array starts at 0)
ReDim strProjects(objDS.Enumerator.Count - 1)

For intCounter = 1 To objDS.Enumerator.Count
    strProjects(intCounter - 1) = objDS.Enumerator.Item(intCounter).ProjectName
Next

' destroy variable and return
Set objProjectDS = Nothing
readProjects = True
Exit Function

' Do the error handling
err_Handler:

' raise error with the original error number if error was not handled before
'strErrorMessage = ERR_READ_PROJECTS_GENERAL & "modMSTR7Helper:readProjects" & Err.Number & ":" & Err.Number & ":" & Err.Source

End Function

'*******************************************************************************
'
' End of Function:     readProjects
'
'*******************************************************************************




'*******************************************************************************
'
' Function:     LogIntoProject
'
' FunctionID:   4
'
' Author:       Hanno Wiegard
'
' Purpose:      logs user with the given userid and password into the project
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     strUID              - username for the project
'               strPWD              - password for the project
'               bolNTSecurity       - use NT security (true = yes)
'               intProject          - index of the project source
'       IN/OUT: None
'       OUT:    strErrorMessage     - error message if not successful
'                                     empty string  otherwise
'
'-------------------------------------------------------------------------------
'
' History:  06/17/2000  HW  Creation
'
'*******************************************************************************

Function LogIntoProject(strUID As String, strPWD As String, bolNTSecurity As Boolean, intProject As Integer, strErrorMessage As String) As Boolean

On Error GoTo err_Handler

Dim objProjDS As IDSSDataSource

' assume failure of the this function
LogIntoProject = False

' Set Data Source to the selected project (identified by the id)
Set objProjDS = objDS.Enumerator.Item(intProject + 1)

' set login mode to standard and pass UID/PWD
If bolNTSecurity = 1 Then
    objProjDS.AuthMode = DssAuthNTCredential
Else
    objProjDS.AuthMode = DssAuthStandard
    objProjDS.login = strUID
    objProjDS.Passwd = strPWD
End If

objProjDS.Init
bolSession = True

' create a new session
Set objSession = objProjDS.CreateSession

LogIntoProject = True
Exit Function

' Do the error handling
err_Handler:

' raise error with the original error number if error was not handled before
'strErrorMessage = ERR_LOGINTOPPROEJCT_GENERAL & "modMSTR7Helper:LogIntoProject" & Err.Number & ":" & Err.Number & ":" & Err.Source

End Function

'*******************************************************************************
'
' End of Function:     LogIntoProject
'
'*******************************************************************************


'*******************************************************************************
'
' Function:     LogIntoProjectSourceN
'
' FunctionID:   13
'
' Author:       Hanno Wiegard
'
' Purpose:      log into project source via project source name
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     strUID              - username for the project
'               strPWD              - password for the project
'               bolNTSecurity       - use NT security (true = yes)
'               strProjectSource    - project source name
'       IN/OUT: None
'       OUT:    strErrorMessage     - error message if not successful
'                                     empty string  otherwise
'
'-------------------------------------------------------------------------------
'
' History:  03/19/2001  HW  Creation
'
'*******************************************************************************

Function LogIntoProjectSourceN(strUID As String, strPWD As String, bolNTSecurity As Boolean, strProjectSource As String, strErrorMessage As String) As Boolean

Dim arrProjectSources() As String       ' list of project source
Dim strErrMsg As String                 ' error message
Dim bolSuccess As Boolean               ' success indicator
Dim i As Integer                        ' counter

bolSuccess = False
    
bolSuccess = readProjectSources(arrProjectSources, strErrMsg)

If bolSuccess Then
    bolSuccess = False
    For i = 0 To UBound(arrProjectSources())
        If StrComp(UCase(Trim(arrProjectSources(i, 1))), UCase(strProjectSource), vbBinaryCompare) = 0 Then Exit For
    Next
    bolSuccess = LogIntoProjectSource(strUID, strPWD, False, i, strErrMsg)
    If bolSuccess Then
        LogIntoProjectSourceN = True
    Else
        LogIntoProjectSourceN = False
        strErrorMessage = strErrMsg
    End If
Else
    LogIntoProjectSourceN = False
    strErrorMessage = strErrMsg
End If


End Function

'*******************************************************************************
'
' End of Function:     LogIntoProjectSourceN
'
'*******************************************************************************





'*******************************************************************************
'
' Function:     LogIntoProjectN
'
' FunctionID:   14
'
' Author:       Hanno Wiegard
'
' Purpose:      logs user with the given userid and password into the project via
'               project name
'
' Remarks:      None
'
'-------------------------------------------------------------------------------
'
' Return Value: True  if error
'               False otherwise
'
'-------------------------------------------------------------------------------
'
' Parameter:
'
'       IN:     strUID              - username for the project
'               strPWD              - password for the project
'               bolNTSecurity       - use NT security (true = yes)
'               strProject          - project name
'       IN/OUT: None
'       OUT:    strErrorMessage     - error message if not successful
'                                     empty string  otherwise
'
'-------------------------------------------------------------------------------
'
' History:  03/19/2001  HW  Creation
'
'*******************************************************************************

Function LogIntoProjectN(strUID As String, strPWD As String, bolNTSecurity As Boolean, strProject As String, strErrorMessage As String) As Boolean

Dim arrProjects() As String             ' list of projects
Dim strErrMsg As String                 ' error message
Dim bolSuccess As Boolean               ' success indicator
Dim i As Integer                        ' counter

bolSuccess = False

bolSuccess = readProjects(arrProjects, strErrMsg)

If bolSuccess Then
    bolSuccess = False
    For i = 0 To UBound(arrProjects())
        If StrComp(UCase(Trim(arrProjects(i))), UCase(strProject), vbBinaryCompare) = 0 Then Exit For
    Next
    If UBound(arrProjects()) >= i Then
        bolSuccess = LogIntoProject(strUID, strPWD, False, i, strErrMsg)
    Else
        strErrMsg = "Couldn't find 2-tier project"
    End If
    If bolSuccess Then
        LogIntoProjectN = True
    Else
        LogIntoProjectN = False
        strErrorMessage = strErrMsg
    End If
Else
    LogIntoProjectN = False
    strErrorMessage = strErrMsg
End If
End Function

'*******************************************************************************
'
' End of Function:     LogIntoProjectN
'
'*******************************************************************************

'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
'+ Procedure:   ConnectToDataSourceAndProject
'+ Purpose:     establish connection to the data source and to the project
'+ Returns :    1 success, 0 failure
'+ History:     Bernd Wiehl, June 2001
'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Function ConnectToDataSourceAndProject(sUID As String, sPWD As String, sDSN As String, sProject As String)

    Dim sErrMsg As String
    Dim bSuccess As Boolean
    
    ConnectToDataSourceAndProject = 0
    
    If Not (Len(sDSN) > 0) And (Len(sProject) > 0) And (Len(sUID) > 0) Then
        'Call showHelp
        Exit Function
    End If
    
    ' try to connect to data source and project
    'Print #iLogFileNum, Time & "Trying to connect to " & sDSN & " using "; sUID & ":" & sPWD
    bSuccess = LogIntoProjectSourceN(sUID, sPWD, False, sDSN, sErrMsg)
    If Not bSuccess Then
        'Print #iLogFileNum, Time & "Error connecting to data source: " & sErrMsg
        Exit Function
    End If
    'Print #iLogFileNum, Time & "Connected to datasource, now connect to the project " & sProject & " using "; sUID & ":" & sPWD
    
    bSuccess = LogIntoProjectN(sUID, sPWD, False, sProject, sErrMsg)
    If Not bSuccess Then
        'Print #iLogFileNum, Time & ": " & "Error connecting to project: " & sErrMsg
        Exit Function
    End If
        
    ConnectToDataSourceAndProject = 1 'success
    'Print #iLogFileNum, Time & " Connected" & vbCrLf

End Function

Public Sub logOutUser()
    If bolSession Then
        objSession.DataSource.Reset
        objSession.Close
        Set objSession = Nothing
        bolSession = False
    End If
End Sub

